# SimplyPrint - the all in one cloud platform for your 3D printer(s)

This is the "SimplyPrint Cloud" plugin for OctoPrint, which connects your 3D printer(s) to the [SimplyPrint](https://simplyprint.io/) platform.

SimplyPrint is a new cloud platform, and our mission is to make everything much more simple. Here are some of SimplyPrint's features;

- Good, user friendly interface
- Easy access from both computer and smartphone
- Simple setup; get started in 5-10 minutes with the most user friendly setup guide you've seen (probably ;))
- All in one;
  - Slice online in your browser _(if you want to - you can always use any other slicer as well)_
  - Store your 3D files in the cloud, and access them anywhere
  - Print online
  - Monitor your prints online _(livestream, print progress, estimated finish etc.)_
  
  Read more on [https://simplyprint.io/](https://simplyprint.io/)
